@@ -1,18 +1,16 @@
 module Fog
   module Account
-    def self.[](provider)
-      new(:provider => provider)
-    end
+    extend Fog::ServicesMixin
 
-    def self.new(attributes)
-      attributes = attributes.dup
+    def self.new(orig_attributes)
+      attributes = orig_attributes.dup
       provider = attributes.delete(:provider).to_s.downcase.to_sym
 
       if provider == :stormondemand
         require "fog/account/storm_on_demand"
         Fog::Account::StormOnDemand.new(attributes)
       else
-        raise ArgumentError, "#{provider} has no account service"
+        super(orig_attributes)
       end
     end
 
